@@ -1,14 +1,13 @@
 package Reaction::UI::ViewPort::Field::Text;
 
 use Reaction::Class;
-use aliased 'Reaction::UI::ViewPort::Field';
-
 use namespace::clean -except => [ qw(meta) ];
-extends Field;
+use MooseX::Types::Moose qw/Str/;
 
+extends 'Reaction::UI::ViewPort::Field';
+
+has '+value' => (isa => Str);
 
-has '+value' => (isa => 'Str');
 __PACKAGE__->meta->make_immutable;
 
-
 1;
