@@ -4,9 +4,12 @@ use Reaction::Class;
 use namespace::clean -except => [ qw(meta) ];
 extends 'Reaction::UI::ViewPort';
 
-has uri => ( is => 'rw', isa => 'URI', required => 1);
-has width => ( is => 'rw', isa => 'Int');
-has height => ( is => 'rw', isa => 'Int');
+use MooseX::Types::URI qw/Uri/;
+use MooseX::Types::Moose qw/Int/;
+
+has uri => ( is => 'rw', isa => Uri, required => 1);
+has width => ( is => 'rw', isa => Int);
+has height => ( is => 'rw', isa => Int);
 
 __PACKAGE__->meta->make_immutable;
 
